@@ -69,12 +69,12 @@ def load_class(path):
         mod_name, klass_name = path.rsplit('.', 1)
         mod = import_module(mod_name)
     except AttributeError as e:
-        raise ImproperlyConfigured(u'Error importing %s: "%s"' % (mod_name, e))
+        raise ImproperlyConfigured('Error importing {0}: "{1}"'.format(mod_name, e))
 
     try:
         klass = getattr(mod, klass_name)
     except AttributeError:
-        raise ImproperlyConfigured('Module "%s" does not define a "%s" class' % (mod_name, klass_name))
+        raise ImproperlyConfigured('Module "{0}" does not define a "{1}" class'.format(mod_name, klass_name))
 
     return klass
 
